<?php

namespace THM\DownloadExplorer\Utility;

/***************************************************************
 *
 *  Copyright notice
 *
 *  (c) 2014-2019
 *           Jan Haffner <info@jan-haffner.de>
 *           Rafael Kähm <Rafael@Kaehms.de>
 *           Samuel Mehrbrodt <samuel.mehrbrodt@mni.thm.de>
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use TYPO3\CMS\Extbase\Exception;

/**
 * Class ExtendedSplFileInfo.
 */
class ExtendedSplFileInfo extends \SplFileInfo
{

    /**
     * Array with subfolder and files for current directory.
     *
     * @var array
     */
    protected $subFoldersAndFiles = array();

    /**
     * @var bool
     */
    private $subFolders = false;

    /**
     * @param array $subFoldersAndFiles
     *
     * @throws Exception
     */
    public function setSubFoldersAndFiles($subFoldersAndFiles)
    {
        if ($this->isFile()) {
            throw new Exception('A file(non dir) object of type "THM\DownloadExplorer\HelperClasses\ExtendedSplFileInfo" has no sub folders and -files.', 1408610961);
        }
        $this->subFoldersAndFiles = $subFoldersAndFiles;
        $this->setSubFolders();
    }

    /**
     * @throws Exception
     *
     * @return array
     */
    public function getSubFoldersAndFiles()
    {
        if ($this->isFile()) {
            throw new Exception('A file(non dir) object of type "THM\DownloadExplorer\Utility\ExtendedSplFileInfo" has no sub folders and -files.', 1408610959);
        }

        return $this->subFoldersAndFiles;
    }

    /**
     * @return bool
     */
    private function setSubFolders()
    {
        foreach ($this->subFoldersAndFiles as $child) {
            if ($child->isDir()) {
                $this->subFolders = true;
                return true;
            }
        }
        $this->subFolders = false;
    }

    /**
     * @return bool
     */
    public function getSubFolders()
    {
        return $this->subFolders;
    }
}
