<?php

namespace THM\DownloadExplorer\ViewHelpers;

/***************************************************************
 *
 *  Copyright notice
 *
 *  (c) 2014-2019
 *           Jan Haffner <info@jan-haffner.de>
 *           Rafael Kähm <Rafael@Kaehms.de>
 *           Samuel Mehrbrodt <samuel.mehrbrodt@mni.thm.de>
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * A view helper to indicate whether a file has been added recently.
 */
class NewFileViewHelper extends \TYPO3Fluid\Fluid\Core\ViewHelper\AbstractTagBasedViewHelper
{
    protected $tagName = "span";

    public function initializeArguments()
    {
        $this->registerArgument('modifiedDate', 'integer', 'When was the file modified the last time?', true);
        $this->registerArgument('highlightForNHours', 'integer', 'How many hours after the file changed should it be highlighted?', true);
    }

    /**
     * Render a `<span>` to indicate that the file has been changed recently.
     *
     * @return string `<span class="newFile">*</span>` when the file has changed recent. Else empty string.
     */
    public function render()
    {
        $now = new \DateTime("now");
        $modified = new \DateTime();
        $modified->setTimeStamp($this->arguments['modifiedDate']);
        $diff = $now->getTimestamp()-$modified->getTimestamp();
        $highlightForSeconds = intval($this->arguments['highlightForNHours']) * 3600;

        if ($diff < $highlightForSeconds) {
            $this->tag->addAttribute('class', "filetype newfile");
            $this->tag->setContent(' ');

            return $this->tag->render();
        } else {
            return '';
        }
    }
}
